import axios from 'axios';
import type { RouteRecordNormalized } from 'vue-router';
import { UserState } from '@/store/modules/user/types';

const BASE_URL = '/auth';

export interface LoginReq {
  phone?: string;
  email?: string;
  username?: string;
  password?: string;
  captcha: string;
  uuid?: string;
}

export interface LoginRes {
  token: string;
}

export function login(req: LoginReq) {
  return axios.post<LoginRes>(`${BASE_URL}/login`, req);
}

export function logout() {
  return axios.post(`${BASE_URL}/logout`);
}

export function getUserInfo() {
  return axios.get<UserState>(`${BASE_URL}/user/info`);
}

export function listRoute() {
  return axios.get<RouteRecordNormalized[]>(`${BASE_URL}/route`);
}

export function socialAuth(source: string) {
  return axios.get<string>(`${BASE_URL}/${source}`);
}

export function socialLogin(source: string, req: any) {
  return axios.post<LoginRes>(`${BASE_URL}/${source}`, req);
}
